summaryrefslogtreecommitdiff
path: root/libs
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2009-04-30 21:56:40 +0000
committerDavid Robillard <d@drobilla.net>2009-04-30 21:56:40 +0000
commit5385e93cc0b7947d9265668fcb7bcb524589c8f5 (patch)
treec4813c5acb8c235101b3ed84f631b44397de0bee /libs
parentc724b85839d8869a7b08470e11e42e741db46322 (diff)
Rename 'position' parameter of MidiSource::midi_read to clearer 'source_start'.
git-svn-id: svn://localhost/ardour2/branches/3.0@5021 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs')
-rw-r--r--libs/ardour/ardour/midi_source.h8
-rw-r--r--libs/ardour/ardour/smf_source.h2
-rw-r--r--libs/ardour/smf_source.cc4
3 files changed, 7 insertions, 7 deletions
diff --git a/libs/ardour/ardour/smf_source.h b/libs/ardour/ardour/smf_source.h
index 3321a089b7..dc9cbeee55 100644
--- a/libs/ardour/ardour/smf_source.h
+++ b/libs/ardour/ardour/smf_source.h
@@ -52,7 +52,7 @@ public:
bool set_name (const std::string& newname) { return (set_source_name(newname, false) == 0); }
void append_event_unlocked_beats (const Evoral::Event<double>& ev);
- void append_event_unlocked_frames (const Evoral::Event<nframes_t>& ev, sframes_t position);
+ void append_event_unlocked_frames (const Evoral::Event<nframes_t>& ev, sframes_t source_start);
void mark_streaming_midi_write_started (NoteMode mode, sframes_t start_time);
void mark_streaming_write_completed ();
diff --git a/libs/ardour/smf_source.cc b/libs/ardour/smf_source.cc
index 1c08e95360..5c420bf986 100644
--- a/libs/ardour/smf_source.cc
+++ b/libs/ardour/smf_source.cc
@@ -95,7 +95,7 @@ SMFSource::~SMFSource ()
/** All stamps in audio frames */
nframes_t
-SMFSource::read_unlocked (MidiRingBuffer<nframes_t>& destination, sframes_t position,
+SMFSource::read_unlocked (MidiRingBuffer<nframes_t>& destination, sframes_t source_start,
sframes_t start, nframes_t duration,
sframes_t stamp_offset, sframes_t negative_stamp_offset) const
{
@@ -112,7 +112,7 @@ SMFSource::read_unlocked (MidiRingBuffer<nframes_t>& destination, sframes_t posi
size_t scratch_size = 0; // keep track of scratch to minimize reallocs
- BeatsFramesConverter converter(_session, position);
+ BeatsFramesConverter converter(_session, source_start);
const uint64_t start_ticks = (uint64_t)(converter.from(start) * ppqn());
diff --git a/libs/ardour/ardour/midi_source.h b/libs/ardour/ardour/midi_source.h
index e84c21f638..cf49e59458 100644
--- a/libs/ardour/ardour/midi_source.h
+++ b/libs/ardour/ardour/midi_source.h
@@ -50,25 +50,25 @@ class MidiSource : virtual public Source
/** Read the data in a given time range from the MIDI source.
* All time stamps in parameters are in audio frames (even if the source has tempo time).
* \param dst Ring buffer where read events are written
* \param position Start position of the SOURCE in this read context
* \param start Start of range to be read
* \param cnt Length of range to be read (in audio frames)
* \param stamp_offset Offset to add to event times written to dst
* \param negative_stamp_offset Offset to subtract from event times written to dst
*/
virtual nframes_t midi_read (MidiRingBuffer<nframes_t>& dst,
- sframes_t position,
+ sframes_t source_start,
sframes_t start, nframes_t cnt,
sframes_t stamp_offset, sframes_t negative_stamp_offset) const;
virtual nframes_t midi_write (MidiRingBuffer<nframes_t>& src,
- sframes_t position,
+ sframes_t source_start,
nframes_t cnt);
virtual void append_event_unlocked_beats(const Evoral::Event<double>& ev) = 0;
virtual void append_event_unlocked_frames(const Evoral::Event<nframes_t>& ev,
- sframes_t position) = 0;
+ sframes_t source_start) = 0;
virtual sframes_t length (sframes_t pos) const;
virtual void update_length (sframes_t pos, sframes_t cnt);
@@ -50,25 +50,25 @@ class MidiSource : virtual public Source
* All time stamps in parameters are in audio frames (even if the source has tempo time).
* \param dst Ring buffer where read events are written
- * \param position Start position of the SOURCE in this read context
+ * \param source_start Start position of the SOURCE in this read context
* \param start Start of range to be read
* \param cnt Length of range to be read (in audio frames)